# Arcgis Utils

Package combining functions to manage data and interact with the api in the arcgis online via the `arcgis` package developed by ESRI.

## Developing

Make a copy of `.env.sample` (and rename `.env`) and copy your Argis Online credentials (see requirements below).

## Requirements

Arcgis online account credentials stored in `.env`:

- `ARCGIS_ONLINE_PASSWORD`: your password
- `ARCGIS_ONLINE_USER`: your username
